import { Field, TooltipField, CompareType, SplitMapLayers, InteractionConfig } from '@kepler.gl/types';
import { Layer, LayerClassesType } from '@kepler.gl/layers';
import KeplerTable, { Datasets } from '@kepler.gl/table';
import { VisState } from '@kepler.gl/schemas';
import { DataRow } from '@kepler.gl/utils';
export declare type LayersToRender = {
    [layerId: string]: boolean;
};
export declare type AggregationLayerHoverData = {
    points: any[];
    colorValue?: any;
    elevationValue?: any;
};
export declare type LayerHoverProp = {
    data: DataRow | AggregationLayerHoverData | null;
    fields: Field[];
    fieldsToShow: TooltipField[];
    layer: Layer;
    primaryData?: DataRow | AggregationLayerHoverData | null;
    compareType?: CompareType;
};
/**
 * Find default layers from fields
 */
export declare function findDefaultLayer(dataset: KeplerTable, layerClasses: LayerClassesType): Layer[];
/**
 * calculate layer data based on layer type, col Config,
 * return updated layer if colorDomain, dataMap has changed
 */
export declare function calculateLayerData(layer: Layer, state: {
    datasets: Datasets;
}, oldLayerData?: any): {
    layerData: any;
    layer: Layer;
};
/**
 * Calculate props passed to LayerHoverInfo
 * @type {typeof import('./layer-utils').getLayerHoverProp}
 */
export declare function getLayerHoverProp({ interactionConfig, hoverInfo, layers, layersToRender, datasets }: {
    interactionConfig: InteractionConfig;
    hoverInfo: any;
    layers: Layer[];
    layersToRender: LayersToRender;
    datasets: Datasets;
}): LayerHoverProp | null;
export declare function renderDeckGlLayer(props: any, layerCallbacks: {
    [key: string]: any;
}, idx: number): any;
export declare function isLayerRenderable(layer: Layer, layerData: any): boolean;
export declare function isLayerVisible(layer: any, mapLayers: any): any;
export declare function prepareLayersForDeck(layers: Layer[], layerData: any[]): {
    [key: string]: boolean;
};
export declare function prepareLayersToRender(layers: Layer[], layerData: VisState['layerData'], mapLayers?: SplitMapLayers | undefined | null): LayersToRender;
export declare function getCustomDeckLayers(deckGlProps: any): any[];
export declare type ComputeDeckLayersProps = {
    mapIndex?: number;
    mapboxApiAccessToken?: string;
    mapboxApiUrl?: string;
    primaryMap?: boolean;
    layersForDeck?: {
        [key: string]: boolean;
    };
};
export declare function computeDeckLayers({ visState, mapState, mapStyle }: any, options?: ComputeDeckLayersProps, onSetLayerDomain?: (idx: number, value: any) => void, deckGlProps?: any): Layer[];
