import React from 'react';
import VisConfigByFieldSelectorFactory from './vis-config-by-field-selector';
import LayerColumnConfigFactory from './layer-column-config';
import LayerTypeSelectorFactory from './layer-type-selector';
import SourceDataSelectorFactory from '../common/source-data-selector';
import VisConfigSwitchFactory from './vis-config-switch';
import VisConfigSliderFactory from './vis-config-slider';
import LayerConfigGroupFactory from './layer-config-group';
import TextLabelPanelFactory from './text-label-panel';
import { ColorRange } from '@kepler.gl/constants';
import { Layer, LayerBaseConfig, VisualChannel, AggregationLayer } from '@kepler.gl/layers';
import { NestedPartial, RGBColor, LayerVisConfig, ColorUI, Field } from '@kepler.gl/types';
import { toggleModal, ActionHandler } from '@kepler.gl/actions';
import { Datasets } from '@kepler.gl/table';
declare type LayerConfiguratorProps = {
    layer: Layer;
    datasets: Datasets;
    layerTypeOptions: {
        id: string;
        label: string;
        icon: React.ElementType;
        requireData: boolean;
    }[];
    openModal: ActionHandler<typeof toggleModal>;
    updateLayerConfig: (newConfig: Partial<LayerBaseConfig>) => void;
    updateLayerType: (newType: string) => void;
    updateLayerVisConfig: (newVisConfig: Partial<LayerVisConfig>) => void;
    updateLayerVisualChannelConfig: (newConfig: Partial<LayerBaseConfig>, channel: string, newVisConfig?: Partial<LayerVisConfig>) => void;
    updateLayerColorUI: (prop: string, newConfig: NestedPartial<ColorUI>) => void;
    updateLayerTextLabel: (idx: number | 'all', prop: string, value: any) => void;
};
declare type LayerColorSelectorProps = {
    layer: Layer;
    onChange: (v: Record<string, RGBColor>) => void;
    selectedColor?: RGBColor;
    property?: string;
    setColorUI: (prop: string, newConfig: NestedPartial<ColorUI>) => void;
};
declare type ArcLayerColorSelectorProps = {
    layer: Layer;
    onChangeConfig: (v: {
        color: RGBColor;
    }) => void;
    onChangeVisConfig: (v: {
        targetColor: RGBColor;
    }) => void;
    property?: string;
    setColorUI: (prop: string, newConfig: NestedPartial<ColorUI>) => void;
};
declare type LayerColorRangeSelectorProps = {
    layer: Layer;
    onChange: (v: Record<string, ColorRange>) => void;
    property?: string;
    setColorUI: (prop: string, newConfig: NestedPartial<ColorUI>) => void;
};
declare type ChannelByValueSelectorProps = {
    layer: Layer;
    channel: VisualChannel;
    onChange: (val: Record<string, string | number | boolean | object | readonly (string | number | boolean | object)[] | null>, key: string) => void;
    fields: Field[];
    description: string;
};
declare type AggregationSelectorProps = {
    channel: VisualChannel;
    layer: AggregationLayer;
    onChange: (val: Record<string, string | number | boolean | object | readonly (string | number | boolean | object)[] | null>, key: string) => void;
};
export declare const getLayerFields: (datasets: Datasets, layer: Layer) => Field[];
export declare const getLayerDataset: (datasets: Datasets, layer: Layer) => import("@kepler.gl/table/dist/kepler-table").default | null;
export declare const getLayerConfiguratorProps: (props: LayerConfiguratorProps) => {
    layer: Layer;
    fields: Field[];
    onChange: (newConfig: Partial<LayerBaseConfig>) => void;
    setColorUI: (prop: string, newConfig: NestedPartial<ColorUI>) => void;
};
export declare const getVisConfiguratorProps: (props: LayerConfiguratorProps) => {
    layer: Layer;
    fields: Field[];
    onChange: (newVisConfig: Partial<LayerVisConfig>) => void;
    setColorUI: (prop: string, newConfig: NestedPartial<ColorUI>) => void;
};
export declare const getLayerChannelConfigProps: (props: LayerConfiguratorProps) => {
    layer: Layer;
    fields: Field[];
    onChange: (newConfig: Partial<LayerBaseConfig>, channel: string, newVisConfig?: Partial<LayerVisConfig> | undefined) => void;
};
declare function LayerConfiguratorFactory(SourceDataSelector: ReturnType<typeof SourceDataSelectorFactory>, VisConfigSlider: ReturnType<typeof VisConfigSliderFactory>, TextLabelPanel: ReturnType<typeof TextLabelPanelFactory>, LayerConfigGroup: ReturnType<typeof LayerConfigGroupFactory>, ChannelByValueSelector: ReturnType<typeof ChannelByValueSelectorFactory>, LayerColumnConfig: ReturnType<typeof LayerColumnConfigFactory>, LayerTypeSelector: ReturnType<typeof LayerTypeSelectorFactory>, VisConfigSwitch: ReturnType<typeof VisConfigSwitchFactory>): React.ComponentType<LayerConfiguratorProps>;
declare namespace LayerConfiguratorFactory {
    var deps: (typeof LayerColumnConfigFactory | typeof LayerTypeSelectorFactory | typeof VisConfigSliderFactory | typeof VisConfigSwitchFactory | typeof LayerConfigGroupFactory | typeof SourceDataSelectorFactory | typeof TextLabelPanelFactory | typeof ChannelByValueSelectorFactory)[];
}
export default LayerConfiguratorFactory;
export declare const LayerColorSelector: ({ layer, onChange, selectedColor, property, setColorUI }: LayerColorSelectorProps) => JSX.Element;
export declare const ArcLayerColorSelector: ({ layer, onChangeConfig, onChangeVisConfig, property, setColorUI }: ArcLayerColorSelectorProps) => JSX.Element;
export declare const LayerColorRangeSelector: ({ layer, onChange, property, setColorUI }: LayerColorRangeSelectorProps) => JSX.Element;
export declare function ChannelByValueSelectorFactory(VisConfigByFieldSelector: ReturnType<typeof VisConfigByFieldSelectorFactory>): ({ layer, channel, onChange, fields, description }: ChannelByValueSelectorProps) => JSX.Element;
export declare namespace ChannelByValueSelectorFactory {
    var deps: (typeof VisConfigByFieldSelectorFactory)[];
}
export declare const AggregationScaleSelector: ({ channel, layer, onChange }: AggregationSelectorProps) => JSX.Element | null;
export declare const AggregationTypeSelector: ({ channel, layer, onChange }: AggregationSelectorProps) => JSX.Element;
