/// <reference types="react" />
/// <reference types="@danmarshall/deckgl-typings/deck.gl__geo-layers" />
import Layer, { LayerBaseConfig, LayerColumn } from '../base-layer';
import { TripsLayer as DeckGLTripsLayer } from '@deck.gl/geo-layers';
import { ColorRange } from '@kepler.gl/constants';
import TripLayerIcon from './trip-layer-icon';
import { GeojsonDataMaps } from '../geojson-layer/geojson-utils';
import { Merge, VisConfigColorRange, VisConfigNumber, VisConfigRange } from '@kepler.gl/types';
import { default as KeplerTable } from '@kepler.gl/table';
import { DataContainerInterface } from '@kepler.gl/utils';
export declare type TripLayerVisConfigSettings = {
    opacity: VisConfigNumber;
    thickness: VisConfigNumber;
    colorRange: VisConfigColorRange;
    trailLength: VisConfigNumber;
    sizeRange: VisConfigRange;
};
export declare type TripLayerColumnsConfig = {
    geojson: LayerColumn;
};
export declare type TripLayerVisConfig = {
    opacity: number;
    thickness: number;
    colorRange: ColorRange;
    trailLength: number;
    sizeRange: [number, number];
};
export declare type TripLayerConfig = Merge<LayerBaseConfig, {
    columns: TripLayerColumnsConfig;
    visConfig: TripLayerVisConfig;
}>;
export declare type TripLayerMeta = {
    getFeature: any;
};
export declare const defaultThickness = 0.5;
export declare const defaultLineWidth = 1;
export declare const tripVisConfigs: {
    opacity: 'opacity';
    thickness: VisConfigNumber;
    colorRange: 'colorRange';
    trailLength: 'trailLength';
    sizeRange: 'strokeWidthRange';
};
export declare const geoJsonRequiredColumns: ['geojson'];
export declare const featureAccessor: ({ geojson }: TripLayerColumnsConfig) => (dc: DataContainerInterface) => (d: any) => any;
export declare const featureResolver: ({ geojson }: TripLayerColumnsConfig) => number;
export default class TripLayer extends Layer {
    visConfigSettings: TripLayerVisConfigSettings;
    config: TripLayerConfig;
    meta: TripLayerMeta;
    dataToFeature: GeojsonDataMaps;
    dataToTimeStamp: {}[];
    getFeature: (columns: TripLayerColumnsConfig) => (dataContainer: DataContainerInterface) => any;
    _layerInfoModal: () => JSX.Element;
    constructor(props: any);
    static get type(): 'trip';
    get type(): "trip";
    get name(): 'Trip';
    get layerIcon(): typeof TripLayerIcon;
    get columnPairs(): import("../base-layer").ColumnPairs;
    get requiredLayerColumns(): ["geojson"];
    get visualChannels(): {
        color: {
            accessor: string;
            nullValue: any;
            getAttributeValue: (config: any) => (d: any) => any;
            defaultValue: (config: any) => any;
            property: string;
            field: string;
            scale: string;
            domain: string;
            range: string;
            key: string;
            channelScaleType: string;
            defaultMeasure?: any;
            condition?: ((config: any) => boolean) | undefined;
            fixed?: any;
            supportedFieldTypes?: ("string" | "boolean" | "date" | "point" | "geojson" | "integer" | "real" | "timestamp")[] | undefined;
            aggregation?: import("../base-layer").VisualChannelAggregation | undefined;
        };
        size: {
            property: string;
            accessor: string;
            condition: (config: any) => any;
            nullValue: number;
            getAttributeValue: () => (d: any) => any;
            field: string;
            scale: string;
            domain: string;
            range: string;
            key: string;
            channelScaleType: string;
            defaultMeasure?: any;
            defaultValue?: any;
            fixed?: any;
            supportedFieldTypes?: ("string" | "boolean" | "date" | "point" | "geojson" | "integer" | "real" | "timestamp")[] | undefined;
            aggregation?: import("../base-layer").VisualChannelAggregation | undefined;
        };
    };
    get animationDomain(): null | undefined;
    get layerInfoModal(): {
        id: string;
        template: () => JSX.Element;
        modalProps: {
            title: string;
        };
    };
    getPositionAccessor(dataContainer: DataContainerInterface): any;
    static findDefaultLayerProps({ label, fields, dataContainer, id }: KeplerTable, foundLayers: any[]): {
        props: {
            label: string;
            columns: any;
            isVisible: boolean;
        }[];
        foundLayers: any[];
    } | {
        props: never[];
        foundLayers?: undefined;
    };
    getDefaultLayerConfig(props: any): {
        animation: {
            enabled: boolean;
            domain: null;
        };
        dataId: string | null;
        label: string;
        color: import("@kepler.gl/types").RGBColor;
        columns: import("../base-layer").LayerColumns;
        isVisible: boolean;
        isConfigActive: boolean;
        highlightColor: import("@kepler.gl/types").RGBColor | import("@kepler.gl/types").RGBAColor;
        hidden: boolean;
        visConfig: import("@kepler.gl/types").LayerVisConfig;
        textLabel: import("@kepler.gl/types").LayerTextLabel[];
        colorUI: {
            color: import("@kepler.gl/types").ColorUI;
            colorRange: import("@kepler.gl/types").ColorUI;
        };
        colorField?: import("../base-layer").VisualChannelField | undefined;
        colorDomain?: import("../base-layer").VisualChannelDomain | undefined;
        colorScale?: "ordinal" | "quantile" | "quantize" | "linear" | "sqrt" | "log" | "point" | undefined;
        sizeDomain?: import("../base-layer").VisualChannelDomain | undefined;
        sizeScale?: "ordinal" | "quantile" | "quantize" | "linear" | "sqrt" | "log" | "point" | undefined;
        sizeField?: import("../base-layer").VisualChannelField | undefined;
    };
    getHoverData(object: any, dataContainer: any): any;
    calculateDataAttribute({ dataContainer, filteredIndex }: {
        dataContainer: any;
        filteredIndex: any;
    }, getPosition: any): any;
    formatLayerData(datasets: any, oldLayerData: any): {};
    updateAnimationDomain(domain: any): void;
    updateLayerMeta(dataContainer: any): void;
    setInitialLayerConfig({ dataContainer }: {
        dataContainer: any;
    }): this;
    renderLayer(opts: any): DeckGLTripsLayer<unknown, import("@deck.gl/geo-layers/trips-layer/trips-layer").TripsLayerProps<unknown>>[];
}
