export declare const LOCALES: {
    en: string;
    fi: string;
    pt: string;
    es: string;
    ca: string;
    ja: string;
    cn: string;
    ru: string;
};
/**
 * Localization can be passed to `KeplerGl` via uiState `locale`.
 * Available languages are `en` and `fi`. Default language is `en`
 * @constant
 * @public
 * @example
 * ```js
 * import {combineReducers} from 'redux';
 * import {LOCALE_CODES} from 'kepler.gl/localization';
 *
 * const customizedKeplerGlReducer = keplerGlReducer
 *   .initialState({
 *     uiState: {
 *       // use Finnish locale
 *       locale: LOCALE_CODES.fi
 *     }
 *   });
 *
 * ```
 */
export declare type LocaleCodesType = {
    [key: string]: string;
};
export declare const LOCALE_CODES: LocaleCodesType;
